import sys
if len(sys.argv) != 3:
    print "command is 'python <python driver code> <script name> <number of time steps>'"
    sys.exit(1)
import paraview
import paraview.vtk as vtk

extent = [0, 10, 0, 12, 0, 12]

def coProcess(grid, time, step, scriptname):
    import vtkCoProcessorPython # import libvtkCoProcessorPython for older PV versions
    if scriptname.endswith(".py"):
        scriptname = scriptname[0:len(scriptname)-3]#scriptname.rstrip(".py")
    try:
        cpscript = __import__(scriptname)
    except:
        print 'Cannot find ', scriptname, ' -- no coprocessing will be performed.'
        return

    datadescription = vtkCoProcessorPython.vtkCPDataDescription()
    datadescription.SetTimeData(time, step)
    datadescription.AddInput("input")
    cpscript.RequestDataDescription(datadescription)
    inputdescription = datadescription.GetInputDescriptionByName("input")
    if inputdescription.GetIfGridIsNecessary() == False:
        return

    inputdescription.SetGrid(grid)
    inputdescription.SetWholeExtent(extent)
    cpscript.DoCoProcessing(datadescription)

try:
    numsteps = int(sys.argv[2])
except ValueError:
    print 'the last argument should be a number, setting the number of time steps to 10'
    numsteps = 10

for step in range(numsteps):
    # assume simulation time starts at 0
    time = step/float(numsteps)

    # create the input to the coprocessing library.  normally
    # this will come from the adaptor
    imageData = vtk.vtkImageData()
    imageData.SetOrigin(0, 0, 0)
    imageData.SetSpacing(.1, .1, .1)
    imageData.SetExtent(extent)
    pointArray = vtk.vtkDoubleArray()
    pointArray.SetNumberOfTuples(imageData.GetNumberOfPoints())
    for i in range(imageData.GetNumberOfPoints()):
        pointArray.SetValue(i, i)
    pointArray.SetName("pointData")
    imageData.GetPointData().AddArray(pointArray)

    # "perform" coprocessing.  results are outputted only if
    # the passed in script says we should at time/step
    coProcess(imageData, time, step, sys.argv[1])

